`include "define.vh"
module top(
    clk,
    rstn,
    data_a,
    data_b,

    result
	 );
//**********************************************************************
// --- Input/Output Declaration
//**********************************************************************
	localparam NUM_DATA = 32;
	input clk;
	input rstn;
	reg [31:0] mem_data_1 [0:NUM_DATA-1];
    reg [31:0] mem_data_2 [0:NUM_DATA-1];
	output reg   [31:0] data_a;
	output reg   [31:0] data_b;
    output wire  [31:0] result;
	reg [$clog2(NUM_DATA+1):0] i_data;
	
//**********************************************************************
// --- Main core
//**********************************************************************	
	FP_Mult_Top FP_Mult_Top_inst(
        .clk(clk),
        .rstn(rstn),
        `ifdef CE
        .ce(1'b1),
        `endif
        .data_a(data_a),
        .data_b(data_b),
		`ifdef OVERFLOW
        .overflow(overflow),
		`endif
		`ifdef UNDERFLOW
        .underflow(underflow),
		`endif
		`ifdef NAN
        .nan(nan),
		`endif
		`ifdef ZERO
		.zero(zero),
		`endif
        .result(result)
    );
	
	always @(posedge clk or negedge rstn) begin
		if(!rstn) begin
			i_data <= 0;
		end
		else begin
			i_data <= i_data + 1'b1;
		end
	end
	
	always @(posedge clk or negedge rstn) begin
		if(!rstn) begin
			data_a <= 0;
			data_b <= 0;
		end
		else begin
			data_a <= mem_data_1[i_data];
			data_b <= mem_data_2[i_data];
		end
	end
	
	initial begin
		$readmemh("data/x.dat",mem_data_1);
		$readmemh("data/y.dat",mem_data_2);
	end

endmodule
